{ config, pkgs, ... }:

{
  
  home.username = "aaronh";
  home.homeDirectory = "/home/aaronh";
  home.stateVersion = "24.05";

  nixpkgs.config = {
    allowUnfree = true;
  };

  home.packages = with pkgs; [
    bat
    bottom
    cargo
    eza
    fastfetch
    fd
    freshfetch
    gcc
    gnumake
    go
    himalaya
    pkg-config
    rustc
  ];

  programs.bash = {
    enable = true;
    shellAliases = {
       home-upgrade = "home-manager switch";
    };
#    bashrcExtra = "eval `ssh-agent`";
  };

  programs.git = {
    enable = true;
    lfs.enable = true;
    userName = "Aaron Honeycutt";
    userEmail = "aaronhoneycutt@protonmail.com";
    aliases = {
       undo = "reset HEAD~1 --mixed";
       amend = "commit -a --amend";
       feature = "commit -m feat: -m new-feature";
       fix = "commit -m fix: -m issue#";
    };
    extraConfig = {
      core.editor = "hx";
      color = {
         ui = "auto";
      };
      color.status = {
         added = "green bold";
         changed = "yellow bold";
         untracked = "red bold";
      };
      push = {
         autoSetupRemote = "true";
      };
      init = {
          defaultBranch = "main";
      };
    };
  };

  programs.gh.enable = true;

  programs.helix = {
    enable = true;
    settings = { 
       theme = "onedark";
    };
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

}
